package pwc.taxtech.atms.controller;

import com.alibaba.fastjson.JSONArray;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import pwc.taxtech.atms.common.message.ErrorMessage;
import pwc.taxtech.atms.constant.enums.BackLogEnum;
import pwc.taxtech.atms.constant.enums.EnumImportType;
import pwc.taxtech.atms.constant.enums.FileUploadEnum;
import pwc.taxtech.atms.dto.ApiResultDto;
import pwc.taxtech.atms.dto.OperationResultDto;
import pwc.taxtech.atms.dto.backlogManage.*;
import pwc.taxtech.atms.dto.input.CamelPagingResultDto;
import pwc.taxtech.atms.exception.ServiceException;
import pwc.taxtech.atms.service.impl.BacklogManageService;
import pwc.taxtech.atms.service.impl.DidiFileUploadService;
import pwc.taxtech.atms.vat.entity.FileUpload;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.util.List;
import java.util.zip.ZipOutputStream;


@RestController
@RequestMapping(value = "api/v1/backlogManage")
public class BacklogManageController extends BaseController {

    @Resource
    private BacklogManageService backlogManageService;

    @Resource
    private DidiFileUploadService didiFileUploadService;

    @GetMapping("/backlog/calendar/type")
    public List<BacklogTypeResult> queryTypeForCalendar() {

        return backlogManageService.queryBacklogType(true);
    }


    @PostMapping("/backlog/detail")
    public CamelPagingResultDto<BacklogDetailResult> queryBacklogDetail(@RequestBody BacklogDetailQueryParam param) {
        return new CamelPagingResultDto<>(backlogManageService.queryBacklogDetail(param));
    }

    @PostMapping("/backlog/detail/group")
    public List<BacklogDetailResult> queryBacklogDetailForGroup(@RequestBody BacklogDetailQueryParam param) {
        return backlogManageService.queryBacklogDetailForGroup(param);
    }


    @PostMapping("/backlog/detail/calendar")
    public List<BacklogCalendarResult> queryBacklogCalendarView(@RequestBody BacklogDetailQueryParam param) {
        return backlogManageService.queryBacklogCalendar(param);
    }

    @PostMapping("/backlog/log")
    public List<BacklogLogResult> queryBacklogLog(@RequestBody BacklogLogQueryParam param) {
        return backlogManageService.queryBacklogLog(param);
    }

    @PostMapping("/backlog/config/common")
    public CamelPagingResultDto<BacklogConfigCommonResult> queryBacklogConfigCommon(@RequestBody BacklogConfigCommonQueryParam param) {
        return new CamelPagingResultDto<>(backlogManageService.queryBacklogConfigCommon(param));
    }

    @GetMapping("/backlog/config/common/selected")
    public List<BacklogConfigCommonResult> querySelectedBacklogConfigCommon() {
        return backlogManageService.querySelectedBacklogConfigCommon();
    }

    @PostMapping("/backlog/config")
    public CamelPagingResultDto<BacklogConfigResult> queryBacklogConfig(@RequestBody BacklogConfigQueryParam param) {
        return new CamelPagingResultDto<>(backlogManageService.queryBacklogConfig(param));
    }

    @PostMapping("/backlog/group")
    public CamelPagingResultDto<BacklogGroupResult> queryBacklogGroup(@RequestBody BacklogGroupQueryParam param) {
        return new CamelPagingResultDto<>(backlogManageService.queryBacklogGroup(param));
    }

    @PostMapping("/backlog/group/detail")
    public CamelPagingResultDto<BacklogGroupResult> queryBacklogGroupDetail(@RequestBody BacklogGroupQueryParam param) {
        return new CamelPagingResultDto<>(backlogManageService.queryBacklogGroupDetail(param));
    }

    @PostMapping("/backlog/disable")
    public ApiResultDto disableBacklog(@RequestBody BacklogDisableParam param) {
        return backlogManageService.disableBacklog(param);
    }

    @PostMapping("/backlog/config/common/edit")
    public ApiResultDto editBacklogConfigCommon(@RequestBody @Valid BacklogConfigCommonEditParam editParam) {
        return backlogManageService.editBacklogConfigCommon(editParam);
    }

    @PostMapping("/backlog/config/edit")
    public ApiResultDto editBacklogConfig(@RequestBody @Valid BacklogConfigEditParam editParam) {
        String errorMsg = "";
        if (editParam.getChoose().intValue() == 1) {
            if (StringUtils.isBlank(editParam.getOrgId())) {
                errorMsg += "BCLAllotColumnOrgError,";
            }
        } else if (editParam.getChoose().intValue() == 2) {
            if(StringUtils.isBlank(editParam.getBusinessLineId())){
                errorMsg += "BCLAllotColumnBusinessError,";
            }
        }
        if (BackLogEnum.GenerateType.ONCE.getCode().equals(editParam.getGenerateType())) {
            if (editParam.getValidityStartDate() == null) {
                errorMsg += "BCLAllotColumnStartDateError,";
            }
            if (editParam.getValidityEndDate() == null) {
                errorMsg += "BCLAllotColumnEndDateError,";
            }
        } else if (BackLogEnum.GenerateType.CYCLE.getCode().equals(editParam.getGenerateType())) {
            if (editParam.getValidityStartDate() == null || editParam.getValidityEndDate() == null) {
                errorMsg += "BCLAllotColumnValidityError,";
            }
            if (StringUtils.isBlank(editParam.getWarnMonth())) {
                errorMsg += "BCLAllotColumnMonthError,";
            }else {
                JSONArray array = JSONArray.parseArray(editParam.getWarnMonth());
                if (array.size() == 0){
                    errorMsg += "BCLAllotColumnMonthError,";
                }
            }
            if (StringUtils.isBlank(editParam.getWarnStartDay())) {
                errorMsg += "BCLAllotColumnStartDayError,";
            }
            if (StringUtils.isBlank(editParam.getWarnEndDay())) {
                errorMsg += "BCLAllotColumnEndDayError,";
            }
            if (StringUtils.isBlank(editParam.getWarnStartTime())) {
                errorMsg += "BCLAllotColumnStartTimeError,";
            }
            if (StringUtils.isBlank(editParam.getWarnEndTime())) {
                errorMsg += "BCLAllotColumnEndTimeError,";
            }
        }
        if (StringUtils.isNotBlank(errorMsg)) {
            return ApiResultDto.fail(errorMsg);
        }

        return backlogManageService.editBacklogConfig(editParam);
    }

    @PostMapping("/backlog/group/edit")
    public ApiResultDto editBacklogGroup(@RequestBody @Valid BackloGroupEditParam editParam) {
        return backlogManageService.editBacklogGroup(editParam);
    }

    @PostMapping("/backlog/detail/status")
    public ApiResultDto editBacklogDetailStatus(@RequestBody BacklogDetailStatusEditParam editParam) {
        return backlogManageService.editBacklogDetailStatus(editParam);
    }

    @PostMapping("/backlog/log/edit")
    public ApiResultDto editBacklogLog(@RequestBody BacklogLogEditParam editParam) {
        return backlogManageService.editBacklogLog(editParam);
    }

    @PostMapping("/backlog/config/group/edit")
    public ApiResultDto editBacklogConfigGroup(@RequestBody BacklogConfigEditListParam editParam) {
        return backlogManageService.editBacklogConfigGroup(editParam);
    }


    @ResponseBody
    @PostMapping("/backlog/upload")
    public OperationResultDto uploadConfigFile(@RequestParam MultipartFile file) {
        try {
            FileUpload upload = didiFileUploadService.uploadFile(file, file.getOriginalFilename(), FileUploadEnum.BizSource.BACK_LOG_CONFIG_UPLOAD.name());
            return OperationResultDto.success(upload);
        } catch (ServiceException e) {
            return OperationResultDto.error(e.getMessage());
        } catch (Exception e) {
            return OperationResultDto.error(ErrorMessage.SystemError);
        }
    }

    @RequestMapping(value = "/backlog/detail/download", method = RequestMethod.POST,
            produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ResponseBody
    public void downloadAllFile(HttpServletResponse response, @RequestBody BacklogDowloadParam dowloadParam) {
        OutputStream outputStream = null;
        ZipOutputStream zos = null;
        try {
            if (CollectionUtils.isNotEmpty(dowloadParam.getFileUploadIds()) && dowloadParam.isZipFlag()) {
                outputStream = response.getOutputStream();
                response.setContentType("multipart/form-data");
                response.setHeader("Content-Disposition", "attachment;fileName=" + URLEncoder.encode("file.zip", "UTF-8"));
                zos = new ZipOutputStream(outputStream);
                backlogManageService.downloadFileForZip(zos, dowloadParam.getFileUploadIds());
            } else if (CollectionUtils.isNotEmpty(dowloadParam.getFileUploadIds())) {
                backlogManageService.downloadFile(response, dowloadParam.getFileUploadIds());
            }

        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                if (zos != null) {
                    zos.close();
                }
                if (outputStream != null) {
                    outputStream.close();
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    @RequestMapping(value = "/backlog/detail/export", method = RequestMethod.POST,
            produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ResponseBody
    public void exportBacklogDetail(@RequestBody BacklogDetailQueryParam param, HttpServletResponse response) {
        OutputStream ouputStream = null;
        try {
            InputStream inputStream = this.getClass().getResourceAsStream("/document/DataImport/" + EnumImportType.BacklogDetail.name() + ".xlsx");
            Workbook tWorkbook = backlogManageService.exportBacklogDetail(inputStream, param);
            response.setContentType("multipart/form-data");
            response.setHeader("Content-Disposition", "attachment;fileName=" + EnumImportType.BacklogDetail.name() + ".xlsx");
            ouputStream = response.getOutputStream();
            tWorkbook.write(ouputStream);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                if (ouputStream != null) {
                    ouputStream.close();
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    @RequestMapping(value = "/backlog/config/export", method = RequestMethod.POST,
            produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ResponseBody
    public void exportBacklogConfig(@RequestBody BacklogConfigCommonQueryParam param, HttpServletResponse response) {
        OutputStream ouputStream = null;
        try {
            InputStream inputStream = this.getClass().getResourceAsStream("/document/DataImport/" + EnumImportType.BacklogConfig.name() + ".xlsx");
            Workbook tWorkbook = backlogManageService.exportBacklogConfig(inputStream, param);
            response.setContentType("multipart/form-data");
            response.setHeader("Content-Disposition", "attachment;fileName=" + EnumImportType.BacklogConfig.name() + ".xlsx");
            ouputStream = response.getOutputStream();
            tWorkbook.write(ouputStream);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                if (ouputStream != null) {
                    ouputStream.close();
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }


    @RequestMapping(value = "/backlog/group/export", method = RequestMethod.POST,
            produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ResponseBody
    public void exportBacklogGroup(@RequestBody BacklogGroupQueryParam param, HttpServletResponse response) {
        OutputStream ouputStream = null;
        try {
            InputStream inputStream = this.getClass().getResourceAsStream("/document/DataImport/" + EnumImportType.BacklogGroup.name() + ".xlsx");
            Workbook tWorkbook = backlogManageService.exportBacklogGroup(inputStream, param);
            response.setContentType("multipart/form-data");
            response.setHeader("Content-Disposition", "attachment;fileName=" + EnumImportType.BacklogGroup.name() + ".xlsx");
            ouputStream = response.getOutputStream();
            tWorkbook.write(ouputStream);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                if (ouputStream != null) {
                    ouputStream.close();
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }
}
