package pwc.taxtech.atms.exception;

import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.BindException;
import org.springframework.validation.BindingResult;
import org.springframework.validation.FieldError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.MissingServletRequestParameterException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.request.WebRequest;
import org.springframework.web.servlet.mvc.method.annotation.ResponseEntityExceptionHandler;
import pwc.taxtech.atms.dto.ApiResultDto;


/**
 * 统一异常处理
 */
//@ControllerAdvice(annotations = RestController.class)
public class RestResponseEntityExceptionHandler extends ResponseEntityExceptionHandler {
    private final Logger logger = LoggerFactory.getLogger(RestResponseEntityExceptionHandler.class);



    /**
     * @Validated 方法参数校验异常处理
     */
    @ExceptionHandler({BindException.class})
    private ResponseEntity<Object> handleConstraintViolationException(BindException e) {
        List<FieldError> violations = e.getBindingResult().getFieldErrors();
        String msg = violations.stream().map(FieldError::getDefaultMessage).collect(Collectors.joining(","));
        return new ResponseEntity<Object>(ApiResultDto.fail(msg), new HttpHeaders(), HttpStatus.OK);
    }

    @ExceptionHandler
    protected ResponseEntity<Object> handleOtherExceptions(Exception ex) {
        logger.error("[Rest Exception]", ex);
        return new ResponseEntity<Object>(ApiResultDto.fail(), new HttpHeaders(), HttpStatus.INTERNAL_SERVER_ERROR);
    }

    @Override
    protected ResponseEntity<Object> handleBindException(BindException ex, HttpHeaders headers, HttpStatus status, WebRequest request) {
        logger.error("[Rest Exception]", ex);
        BindingResult bindingResult = ex.getBindingResult();
        String resultMessage = StringUtils.defaultString(bindingResult.getFieldError().getDefaultMessage(), ApiResultDto.fail().getMessage());
        return new ResponseEntity<Object>(ApiResultDto.fail(resultMessage), new HttpHeaders(), HttpStatus.OK);
    }

    @Override
    protected ResponseEntity<Object> handleMissingServletRequestParameter(MissingServletRequestParameterException ex, HttpHeaders headers, HttpStatus status, WebRequest request) {
        logger.error("[Rest Exception]", ex);
        return new ResponseEntity<Object>(ApiResultDto.fail(), new HttpHeaders(), HttpStatus.OK);
    }

    @Override
    protected ResponseEntity<Object> handleMethodArgumentNotValid(MethodArgumentNotValidException ex, HttpHeaders headers, HttpStatus status, WebRequest request) {
        logger.error("[Rest Exception]", ex);
        BindingResult bindingResult = ex.getBindingResult();
        String resultMessage = StringUtils.defaultString(bindingResult.getFieldError().getDefaultMessage(), ApiResultDto.fail().getMessage());
        return new ResponseEntity<Object>(ApiResultDto.fail(resultMessage), new HttpHeaders(), HttpStatus.OK);
    }
}