package pwc.taxtech.atms.service.impl;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import pwc.taxtech.atms.common.config.SystemConfig;
import pwc.taxtech.atms.common.util.CommonUtil;
import pwc.taxtech.atms.common.util.SnowFlake;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.Map;

@Component
public class DistributedIdService {
    private static final Logger logger = LoggerFactory.getLogger(DistributedIdService.class);
    @Value("${distributed_id_datacenter}")
    private Integer dataCenterId;
    @Value("${distributed_id_machine}")
    private Integer machineId;
    private static final int DEFAULT_MACHINE_ID = 1;
    @Resource
    private SystemConfig systemConfig;

    private SnowFlake snowFlake;


    @PostConstruct
    public void init() throws Exception {
        String ip = CommonUtil.getLocalHostLANAddress().getHostAddress();
        for (Map.Entry<String, String> entry : systemConfig.getIdGeneratorMap().entrySet()) {
            if (StringUtils.trim(entry.getValue()).equals(ip)) {
                snowFlake = new SnowFlake(dataCenterId, Integer.valueOf(entry.getKey()));
                logger.info("初始化 dataCenterId: {} machineId: {}", dataCenterId, Integer.valueOf(entry.getKey()));
                break;
            }
        }
        if (null == snowFlake) {
            snowFlake = new SnowFlake(dataCenterId, DEFAULT_MACHINE_ID);
            logger.info("初始化 dataCenterId: {} machineId: {}", dataCenterId, DEFAULT_MACHINE_ID);
        }
    }

    /**
     * 获取Id
     *
     * @return long
     */
    public long nextId() {
        return snowFlake.nextId();
    }
}
