﻿taxCalendarModule.controller('editCalendarTaskController', ['$scope', '$log', 'uiGridConstants', 'SweetAlert', '$translate', '$interval', 'orgService',
    '$timeout', '$q', 'loginContext', '$uibModal', 'taxCalendarService', 'userService', 'taxCalendarEventService', 'uploadFileService','enums',
    function ($scope, $log, uiGridConstants, SweetAlert, $translate, $interval, orgService, $timeout, $q, loginContext, $uibModal, taxCalendarService,
        userService, taxCalendarEventService, uploadFileService, enums) {
    	'use strict';

    	$scope.vatPermission = constant.vatPermission;
    	// 已经完成未完成状态{1:已经完成，0：未完成}
    	var taxEventFinishStatus = _.invert(constant.EnumTaxEventFinishStatus);

    	var taxEventType = _.invert(constant.EnumTaxEventType);

    	var MAX_WEEK_OF_MONTH = 6;
    	var ARROW_WIDTH_HALF = 8;

    	// 翻译数据
    	var translateVariable = {
    		Finished: $translate.instant('Finished'),
    		NotFinished: $translate.instant('NotFinished'),

            // 自定义事项
    		UserDefine: $translate.instant('UserDefine'),

            // 日历设置事项
    		SystemConfig: $translate.instant('SystemConfig')
    	};

    	var cacheDataService = {
    		userOwnOrg: {}
    	};

    	var popupService = {

    	    locationHander:{},
    		operateType: null,
    		init: function () {
    			// body...
    			$scope.workPlaceList = [{ id: '234234', name: 'test' }];

    			$scope.isRead = false;

    			$scope.finishStatus = [
					{ id: 0, name: translateVariable.NotFinished },
					{ id: 1, name: translateVariable.Finished }
    			];

    			$scope.editModel = {};
    			taxCalendarService.getWorkPlaceList().success(function (result) {
    				if (result) {
    					$scope.workPlaceList = result;
    				}
    			});

    			userService.getUserOwnOrganization(loginContext.userName).success(function (data) {
    				if (data && data.result) {
    					cacheDataService.userOwnOrg = data.data;
    				} else {
    					SweetAlert.warning($translate.instant('SystemException'));
    				}
    			}).error(function (data) {
    				SweetAlert.warning($translate.instant('SystemException'));
    			});

    			popupService.initOptions();

    			popupService.watchCollection();

                //文件上传对象
    			$scope.uploadFile = function () {
    			    $scope.uploadFileType = 'multiple';
    			    $scope.uploadFileOption = {
    			        title: $translate.instant('UploadFileTitle'),
    			        uploadButtonText: $translate.instant('SeleteFile'),
    			        uploadFileType: enums.uploadFileType.calendarDisplay,
    			        files: $scope.editModel.fileList || []
    			    };
    			};

    		    //删除文件
    			$scope.deleteFile = function (fileId) {
    			    SweetAlert.swal({
    			        title: $translate.instant('DeleteConfirm'),
    			        text: $translate.instant('ComfirmDeleteFile'),
    			        type: "warning",
    			        showCancelButton: true,
    			        confirmButtonColor: "#DD6B55",
    			        confirmButtonText: $translate.instant('Confirm'),
    			        cancelButtonText: $translate.instant('Cancel'),
    			        closeOnConfirm: true,
    			        closeOnCancel: true
    		        },
                    function (isConfirm) {
                        if (isConfirm) {
                            uploadFileService.deleteFile(fileId).then(function () {
                                $scope.editModel.fileList = _.filter($scope.editModel.fileList, function (item) {
                                    return item.data.id != fileId;
                                });
                                SweetAlert.success($translate.instant('CommonSuccess'));
                            });
                        }
                    });
    			};

    			$scope.downloadFile = function (fileID) {
    			    uploadFileService.downloadFile(fileID);
    			};

    			$scope.$watch('uploadFileOption.files', function (newValue, oldValue) {
    			    if (newValue && newValue != oldValue) {
    			        $scope.editModel.fileList = $scope.uploadFileOption.files;
    			    }
    			});

    		},
    		initOptions: function () {
    			// body...
    			$scope.addressOptions = {
    				bindingOptions: {
    					dataSource: 'workPlaceList',
    					value: 'editModel.workPlaceID',
    					disabled: 'isReadOnly'
    				},
    				displayExpr: 'name',
    				valueExpr: 'id',
    				searchEnabled: true,
    				showClearButton: true,
    				onValueChanged: function (e) {
    					if (e && e.component) {
    						var data = e.component.option('selectedItem');
    						if (data) {
    							$scope.editModel.workPlaceName = data.name;
    						}
    					}
    				},
    				placeholder: ''
    			};

    			$scope.statusOptions = {
    				bindingOptions: {
    					dataSource: 'finishStatus',
    					value: 'editModel.status',
    					disabled: 'isRead'
    				},
    				displayExpr: 'name',
    				valueExpr: 'id',
    				searchEnabled: false,
    				showClearButton: false
    			};

    			$scope.attachmentRemarkOptions = {
    			    bindingOptions: {
    			        disabled: 'isRead'
    			    },
    			    placeholder: $translate.instant('PleaseInput'),
    			    height: 100,
    			    maxLength: 500
    			};

    			$scope.taxProjectNameValidateOpt = {
    				validationRules: [{
    					type: "required",
    					message: $translate.instant('TaxProjectNameRequire')
    				}]
    			};
    			 
    		},

			// 弹框
    		add: function () {

    		    $scope.saveType = 'add';

    		    $('#editCalendarEventForm').dxValidationGroup("instance").reset();

    		    $scope.isReadOnly = false;
    			if ($scope.operateModel) {
    			    $scope.editModel = $scope.operateModel;
    			    $scope.editModel.taxProjectNameShow = $scope.editModel.taxProjectName;
    				$scope.editModel.id = window.PWC.newGuid();
    				$scope.editModel.eventDate = new Date($scope.operateModel.eventDate).formatDateTime('yyyy-MM-dd');
    				$scope.editModel.statusText = $translate.instant(taxEventFinishStatus[$scope.editModel.status]);
 
    				$scope.styleOptions = {
    				    "border-color": $scope.operateModel.colorGroup.borderColor,
    				    "background-color": $scope.operateModel.colorGroup.borderColor
    				};
    			} else {
    				$scope.editModel = {};
    				$scope.editModel.id = window.PWC.newGuid();
    				$scope.editModel.typeText = $translate.instant(taxEventType[1]);
    			}

    			$scope.isRead = true;
    			$scope.editModel.companyName = cacheDataService.userOwnOrg.name;
    			$scope.editModel.companyID = cacheDataService.userOwnOrg.id;

    			popupService.locationHander = dateLocationService;
    			popupService.show();
    		},

            // 显示详细
            showDetail: function () {
    		    if ($scope.operateModel) {
    		        $scope.editModel = $scope.operateModel;

    		        var showText = $scope.operateModel.taxProjectName;

    		        if ($scope.operateModel.calendarNumber) {
    		            showText += ' ' + $scope.operateModel.calendarNumber;
    		        }

    		        $scope.editModel.taxProjectNameShow = showText;
    		        $scope.editModel.eventDate = new Date($scope.operateModel.eventDate).formatDateTime('yyyy-MM-dd');
    		        $scope.editModel.statusText = $translate.instant(taxEventFinishStatus[$scope.editModel.status]);
    		        $scope.editModel.typeText = $translate.instant(taxEventType[$scope.editModel.type]);
    		        $scope.isReadOnly = true;
    		        $scope.styleOptions = {
    		            "border-color": $scope.operateModel.colorGroup.borderColor,
    		            "background-color": $scope.operateModel.colorGroup.borderColor
    		        };

    		        $scope.saveType = 'query';
    		    }

    		    $scope.isRead = true;
    		    popupService.locationHander = scheduleLocationService;
    		    popupService.show();

    		},

            // 进入编辑状态
            intoEditStatus: function () {
    		    $scope.saveType = 'edit';
    		    if ($scope.editModel.type == constant.EnumTaxEventType.UserDefine) {
    		        $scope.isReadOnly = false;
    		    } else {
    		        $scope.isReadOnly = true;
    		    }

    		    $scope.isRead = false;
    		    popupService.locationHander = dateLocationService;

    		    var bounds = $scope.operateModel._event.target.getBoundingClientRect();
    		    $scope.editModel.guideBound = bounds;
    		    popupService.show();
    		},

            // 删除确认
            confirmDelete: function () {
                //deleteEvent
                SweetAlert.swal({
                    title: $translate.instant('Confirm') + " " + $translate.instant('Delete') + '?',
                    type: "warning",
                    showCancelButton: true,
                    confirmButtonColor: "#DD6B55",
                    confirmButtonText: $translate.instant('Confirm'),
                    cancelButtonText: $translate.instant('Cancel'),
                    closeOnConfirm: true,
                    closeOnCancel: true
                },
                    function (isConfirm) {
                        if (isConfirm) {
                            popupService.saveDelete();
                        }
                    });
    		},

			// 公用部分
    		show: function () {
    		    $('#definitionPopup').css('display', 'block');

    		    $timeout(function () {
    		        try {
    		            $('#definitionPopup').css('visibility', 'visible');
    		            popupService.locationHander.setPostion();
    		        } catch (ex) {
    		            console.log(ex);
    		        }
    		    },10);
    		    

    			$scope.operateType = null;
    		},
    		close: function () {
    		    $('#definitionPopup').css('display', 'none');
    		    $('#definitionPopup').css('visibility', 'hidden');
    			$scope.operateType = null;
    			popupService.operateType = null;

    			if ($('.tui-full-calendar-daygrid-guide-creation-block').length != 0) {
    				$('.tui-full-calendar-daygrid-guide-creation-block').remove();
    			}
    		},

			// Watch
    		watchCollection: function () {
    			$scope.$watch('operateType', function (newValue, oldValue) {
    				if (newValue) {

    				    popupService.operateType = newValue;
    					if (newValue === constant.Operation.Add) {
    						popupService.add();
    					} else if (newValue === constant.Operation.Edit) {

    					} else if (newValue === constant.Operation.Query) {
    					    popupService.showDetail();
    					} else if (newValue === constant.Operation.Close) {
    					    popupService.close();
    					}
    				}
    			});
    		},

    		// 保存
    		saveAdd: function (type) {

                var dxResult = DevExpress.validationEngine.validateGroup($('#editCalendarEventForm').dxValidationGroup("instance")).isValid;
                if (!dxResult) {
                    return;
                }

    		    var model = $scope.editModel;

    		    var paramResultType = type ? type : 'addSuccess';

    		    model.operationDate = new Date();
    		    if (model.status === constant.EnumTaxEventFinishStatus.Finished) {
    		        model.completeUserID = loginContext.userId;
    		        model.completeUserName = loginContext.userName;
    		    }
    		    //添加事项关联的附件
    			//if ($scope.editModel.fileList && $scope.editModel.fileList.length > 0) {
    			//    model.fileList = _.pluck($scope.editModel.fileList, 'data');
    			//}
    			taxCalendarEventService.add(model).success(function (data) {
    				if (data.result) {
    				    if (_.isFunction($scope.onClosed)) {

                            $scope.onClosed({ param: { data: model, type: paramResultType }});
    					}
    					popupService.close();
    				} else {
    					if (data.resultMsg) {
    						SweetAlert.warning($translate.instant(data.resultMsg));
    					} else {
    						SweetAlert.warning($translate.instant('SystemException'));
    					}
    				}
    			}).error(function (data) {
    				$log.debug(data);
    				SweetAlert.warning($translate.instant('SystemException'));
    			});
    		},

    		saveEdit: function () {
    			var model = $scope.editModel;
                //添加事项关联的附件
    			//if ($scope.editModel.fileList && $scope.editModel.fileList.length > 0) {
    			//    model.fileList = _.pluck($scope.files, 'data');
    			//}

    			if (model.status === constant.EnumTaxEventFinishStatus.Finished) {
    			    model.operationDate = new Date();
    			    model.completeUserID = loginContext.userId;
    			    model.completeUserName = loginContext.userName;
    			}

    			taxCalendarEventService.update(model).success(function (data) {
    				if (data.result) {
    					if (_.isFunction($scope.onClosed)) {
                            $scope.onClosed({ param: { data: model, type: 'updateSuccess' } });
    					}

    					popupService.close();
    				} else {
    					if (data.resultMsg) {
    						SweetAlert.warning($translate.instant(data.resultMsg));
    					} else {
    						SweetAlert.warning($translate.instant('SystemException'));
    					}
    				}
    			}).error(function (data) {
    				$log.debug(data);
    				SweetAlert.warning($translate.instant('SystemException'));
    			});
    		},

            saveDelete: function () {
                var model = $scope.editModel;
                taxCalendarEventService.deleteEvent(model).success(function (data) {
                    if (data.result) {
                        if (_.isFunction($scope.onClosed)) {
                            $scope.onClosed({ param: {data:model, type: 'deleteSuccess'} });
                        }

                        popupService.close();
    		    } else {
                        if (data.resultMsg) {
                            SweetAlert.warning($translate.instant(data.resultMsg));
                        } else {
                            SweetAlert.warning($translate.instant('SystemException'));
    		    }
                    }
                }).error(function (data) {
                    $log.debug(data);
                    SweetAlert.warning($translate.instant('SystemException'));
                });
    		},

            saveUpdate: function () {
    			var dxResult = DevExpress.validationEngine.validateGroup($('#editCalendarEventForm').dxValidationGroup("instance")).isValid;
    			if (!dxResult) {
    				return;
    			}

                if ($scope.editModel.type === constant.EnumTaxEventType.UserDefine) {
                    popupService.saveEdit();
                } else {
                    popupService.saveAdd('updateSuccess');
    		    }
            }
    	};


    	var caculateDirectionService = {
            // 纵向位置，上下
    	    calcVerticalRenderingData: function (layerSize, parentSize, guideBound) {
    	        var guideHorizontalCenter = (guideBound.left + guideBound.right) / 2;
    	        var x = guideHorizontalCenter - (layerSize.width / 2);
    	        var y = guideBound.top - layerSize.height + 3;
    	        
    	        var arrowDirection = 'arrow-bottom';
    	        var arrowLeft;

    	        if (y < 0) {
    	            //周日历，重绘弹框位置。
    	            if (window.cal._viewName === 'week') {
    	                y = guideBound.top + 9;
    	                arrowDirection = 'arrow-top';
    	            } else {
    	                y = guideBound.bottom + 9;
    	                arrowDirection = 'arrow-top';
    	            }
    	        }

    	        if (x > 0 && (x + layerSize.width > parentSize.right)) {
    	            x = parentSize.right - layerSize.width;
    	        }

    	        if (x < 0) {
    	            x = 0;
    	        }

    	        if (guideHorizontalCenter - x !== layerSize.width / 2) {
    	            arrowLeft = guideHorizontalCenter - x - ARROW_WIDTH_HALF;
    	        }

    	        /**
				 * @typedef {Object} PopupRenderingData
				 * @property {number} x - left position
				 * @property {number} y - top position
				 * @property {string} arrow.direction - direction of popup arrow
				 * @property {number} [arrow.position] - relative position of popup arrow, if it is not set, arrow appears on the middle of popup
				 */
    	        return {
    	            x: x,
    	            y: y,
    	            arrow: {
    	                direction: arrowDirection,
    	                position: arrowLeft
    	            }
    	        };
    	    },

            // 横向位置，左右，纵向可能被遮住
    	    calcHorizontalRenderingData: function (layerSize, parentSize, guideBound) {
    	        var guideVerticalCenter = (guideBound.top + guideBound.bottom) / 2;
    	        var x = guideBound.right;
    	        var y = guideVerticalCenter;
    	        var arrowDirection = 'arrow-left';
    	        var arrowTop;
    	        var isCover = false;

    	        if (y < 0) {
    	            y = y + (layerSize.height / 2) - guideVerticalCenter;
    	        }

    	        if (x > 0 && (x + layerSize.width > parentSize.right)) {
    	            x = guideBound.left - layerSize.width - ARROW_WIDTH_HALF - 3;
    	            arrowDirection = 'arrow-right';
    	        }

    	        if (x < 0) {
    	            x = 0;
    	        }

    	        if (guideBound.right > x + layerSize.width) {
    	            arrowDirection = 'arrow-right';
    	        }

    	        // 纵向可能被遮住
    	        if (y > 0 && y + (layerSize.height / 2) > parentSize.height) {
    	            isCover = true;
    	        }

    	        /**
                 * @typedef {Object} PopupRenderingData
                 * @property {number} x - left position
                 * @property {number} y - top position
                 * @property {string} arrow.direction - direction of popup arrow
                 * @property {number} [arrow.position] - relative position of popup arrow, if it is not set, arrow appears on the middle of popup
                 */
    	        return {
    	            //x: x + ARROW_WIDTH_HALF,
                    x:x,
    	            //y: y - (layerSize.height / 2) + ARROW_WIDTH_HALF,
    	            y: y - (layerSize.height / 2),
    	            arrow: {
    	                direction: arrowDirection,
    	                position: arrowTop
    	            },
                    // 是否被遮住
    	            isCover: isCover
    	        };
    	    }
    	};

    	var dateLocationService = {

    	    setPostion: function () {
    	        var bounds = null;
    	        if ($scope.editModel.guideBound) {
    	            bounds = $scope.editModel.guideBound;
    	        } else {
    	            bounds = dateLocationService.getGuideBound();
    	        }

    	        dateLocationService.setPopupPositionAndArrowDirection(bounds);
    	    },

			// 默认添加当天的事项
    	    getGuideBound: function () {
    			 
    	        var guideBound = {};

    	        var getWeekBounds = function (current) {

    	            var ret = {};
    	            if ($('.tui-full-calendar-allday-right .tui-full-calendar-weekday-grid-line').length === 7) {

    	                var from = window.cal._renderRange.start;
    	                var a = moment(new Date(current).formatDateTime('yyyy-MM-dd'));
    	                var b = moment(new Date(from).formatDateTime('yyyy-MM-dd'));

    	                var diff = a.diff(b, 'days');
    	                if (diff < 0) {
    	                    diff = 0;
    	                }

    	                if (diff > 6) {
    	                    diff = 6;
    	                }

    	                ret = $('.tui-full-calendar-allday-right .tui-full-calendar-weekday-grid-line').get(diff).getBoundingClientRect();
    	            }

    	            return ret;
    	        };

    			var day = window.cal._renderRange.start.getDate();
    			if ($('.tui-full-calendar-today').length != 0) {

    			    if (window.cal._viewName === 'week') {
                        
    			        guideBound = getWeekBounds($scope.operateModel.eventDate);
    			    } else {
    			        guideBound = $('.tui-full-calendar-today').get(0).getBoundingClientRect();
    			    }
    			}
    			else if ($('.tui-full-calendar-allday-right .tui-full-calendar-weekday-grid-line').length === 7) {
    			    guideBound = getWeekBounds($scope.operateModel.eventDate);
    			} 

    			return guideBound;
    		},

			// 选中日期添加的
    		setPopupPositionAndArrowDirection: function (guideBound) {
    			var layer = $('#definitionPopup').get(0);
    			var layerSize = $('#definitionPopup').get(0).getBoundingClientRect();

    			var windowSize = {
    				right: window.innerWidth,
    				bottom: window.innerHeight
    			};

    			var parentBounds = $('#calendar').get(0).getBoundingClientRect();

    			var pos = dateLocationService.calcRenderingData(layerSize, parentBounds, guideBound);

    			$('#definitionPopup').css("left", pos.x + 'px');
    			$('#definitionPopup').css("top", pos.y + 'px');

    			dateLocationService.setArrowDirection(pos.arrow);
    		},

			// 计算弹出层的位置
    		calcRenderingData: function (layerSize, parentSize, guideBound) {
    		    var data = caculateDirectionService.calcVerticalRenderingData(layerSize, parentSize, guideBound);

    		    return data;
    		},

			// 设置Arrow的位置
    		setArrowDirection: function (arrow) {
    			var direction = arrow.direction || 'arrow-bottom';
    			var arrowEl = $('.popup-arrow');
    			//var borderElement = $('.popup-arrow-border .popup-arrow');

    			$('#tui-full-calendar-popup-arrow').removeClass('tui-full-calendar-arrow-bottom');
    			$('#tui-full-calendar-popup-arrow').removeClass('tui-full-calendar-arrow-left');
    			$('#tui-full-calendar-popup-arrow').removeClass('tui-full-calendar-arrow-right');
    			$('#tui-full-calendar-popup-arrow').removeClass('tui-full-calendar-arrow-top');
    		    $('#tui-full-calendar-popup-arrow').addClass('tui-full-calendar-' + direction);
    			 
    		    var borderElement = $('.tui-full-calendar-popup-arrow-border');
    			if (arrow.position) {
    				borderElement.style.left = arrow.position + 'px';
    			}
    		}
    	};


    	var scheduleLocationService = {

    	    setPostion: function () {

    	        scheduleLocationService.setPopupPositionAndArrowDirection($scope.operateModel._event);
    	    },

    	    getGuideBound: function () {

    	        var guideBound = {};

    	        var day = window.cal._renderRange.start.getDate();
    	        if ($('.tui-full-calendar-daygrid-guide-creation-block').length != 0) {

    	            // 周视图
    	            guideBound = $('.tui-full-calendar-daygrid-guide-creation-block').get(0).getBoundingClientRect();

    	            var rightPart = $('.tui-full-calendar-allday-right').get(0).getBoundingClientRect();
    	            guideBound.top = rightPart.top;
    	        }
    	        else if ($('.tui-full-calendar-today').length != 0) {
    	            guideBound = $('.tui-full-calendar-today').get(0).getBoundingClientRect();
    	        }
    	        else if ($(".tui-full-calendar-weekday-grid-date:eq('" + day + "')").length != 0) {

    	            // 如果是月视图，并且不是当前月份的时间，则定位在每月的1号
    	            var d = $(".tui-full-calendar-weekday-grid-date:eq('1')");
    	            guideBound = d.parent().parent().parent().get(0).getBoundingClientRect();
    	        }

    	        return guideBound;
    	    },

    	    setPopupPositionAndArrowDirection: function (event) {

    	        var guideBound = event.target.getBoundingClientRect();
    	        //var layer = event.getBoundingClientRect();
    	        var layer = $('#definitionPopup').get(0);
    	        var layerSize = $('#definitionPopup').get(0).getBoundingClientRect();

    	        var windowSize = {
    	            right: window.innerWidth,
    	            bottom: window.innerHeight
    	        };

    	        var parentBounds = $('#calendar').get(0).getBoundingClientRect();

    	       //var parentBounds = event.target.parentNode.getBoundingClientRect();

    	        var pos = scheduleLocationService.calcRenderingData(layerSize, parentBounds, guideBound);
    	        //pos.x -= parentBounds.left + 4;
    	        //pos.y -= (parentBounds.top + ARROW_WIDTH_HALF);


    	        $('#definitionPopup').css("left", pos.x + 'px');
    	        $('#definitionPopup').css("top", pos.y + 'px');

    	        scheduleLocationService.setArrowDirection(pos.arrow);
    	    },

    	    calcRenderingData:function(layerSize, parentSize, guideBound){
    	        var result = caculateDirectionService.calcHorizontalRenderingData(layerSize, parentSize, guideBound);
    	        if (result.y < 0) {
    	            result.y = 0;
    	        }
    	        if (result.isCover) {
    	            result = caculateDirectionService.calcVerticalRenderingData(layerSize, parentSize, guideBound);
    	        }

    	        return result;
    	    },

    	    setArrowDirection: function (arrow) {
    	        var arrowEl = $('.popup-arrow');
    	        //var borderElement = $('.popup-arrow-border .popup-arrow');
    	        var direction = arrow.direction || 'arrow-left';
    	        $('#tui-full-calendar-popup-arrow').removeClass('tui-full-calendar-arrow-bottom');
    	        $('#tui-full-calendar-popup-arrow').removeClass('tui-full-calendar-arrow-left');
    	        $('#tui-full-calendar-popup-arrow').removeClass('tui-full-calendar-arrow-right');
    	        $('#tui-full-calendar-popup-arrow').removeClass('tui-full-calendar-arrow-top');
    	        $('#tui-full-calendar-popup-arrow').addClass('tui-full-calendar-' + direction);

    	        var borderElement = $('.tui-full-calendar-popup-arrow-border');
    	        if (arrow.position) {
    	            borderElement.style.left = arrow.position + 'px';
    	        }
    	    }
    	};

    	$scope.$watch('isReadOnly', function () {
    	    if ($scope.isReadOnly) {
    	        $('.dx-texteditor-input').css('padding-right', '20px');
    	    } else {
    	        $('.dx-texteditor-input').css('padding-right', '60px');
    	    }
    	});


    	$scope.popupEvent = {

    		// 关闭
    		close: popupService.close,

    		// 保存
            saveAdd: popupService.saveAdd,

            // 进入编辑状态
    		intoEditStatus: popupService.intoEditStatus,

            // 保存编辑结果
    		saveUpdate: popupService.saveUpdate,

            confirmDelete: popupService.confirmDelete
    	};

    	(function initializa() {
    		popupService.init();
    		$log.debug('editCalendarTaskController.ctor()...');

    	})();
    }
]);